@@ -1,9 +1,9 @@
+import datetime
 import functools
 import json
 import os
 import pathlib
 import shutil
-from functools import singledispatchmethod
 from typing import Any, Self
 
 import tomlkit
@@ -22,10 +22,84 @@ class Pathier(pathlib.Path):
             )
         return self
 
-    def moveup(self, name: str) -> Self:
-        """Return a new Pathier obj that is a parent of this instance.
+    @property
+    def dob(self) -> datetime.datetime | None:
+        """Returns the creation date of this file
+        or directory as a dateime.datetime object."""
+        if self.exists():
+            return datetime.datetime.fromtimestamp(self.stat().st_ctime)
+        else:
+            return None
 
-        :param name: The parent directory that should be the stem of the returned Pathier obj.
+    @property
+    def age(self) -> float | None:
+        """Returns the age in seconds of this file or directory."""
+        if self.exists():
+            return (datetime.datetime.now() - self.dob).total_seconds()
+        else:
+            return None
+
+    @property
+    def mod_date(self) -> datetime.datetime | None:
+        """Returns the modification date of this file
+        or directory as a datetime.datetime object."""
+        if self.exists():
+            return datetime.datetime.fromtimestamp(self.stat().st_mtime)
+        else:
+            return None
+
+    @property
+    def mod_delta(self) -> float | None:
+        """Returns how long ago in seconds this file
+        or directory was modified."""
+        if self.exists():
+            return (datetime.datetime.now() - self.mod_date).total_seconds()
+        else:
+            return None
+
+    def size(self, format: bool = False) -> int | str | None:
+        """Returns the size in bytes of this file or directory.
+        Returns None if this path doesn't exist.
+
+        :param format: If True, return value as a formatted string."""
+        if not self.exists():
+            return None
+        if self.is_file():
+            size = self.stat().st_size
+        if self.is_dir():
+            size = sum(file.stat().st_size for file in self.rglob("*.*"))
+        if format:
+            return self.format_size(size)
+        return size
+
+    @staticmethod
+    def format_size(size: int) -> str:
+        """Format 'size' with common file size abbreviations
+        and rounded to two decimal places.
+        >>> 1234 -> "1.23 kb" """
+        for unit in ["bytes", "kb", "mb", "gb", "tb", "pb"]:
+            if unit != "bytes":
+                size *= 0.001
+            if size < 1000 or unit == "pb":
+                return f"{round(size, 2)} {unit}"
+
+    def is_larger(self, path: Self) -> bool:
+        """Returns whether this file or folder is larger than
+        the one pointed to by 'path'."""
+        return self.size() > path.size()
+
+    def is_older(self, path: Self) -> bool:
+        """Returns whether this file or folder is older than
+        the one pointed to by 'path'."""
+        return self.dob < path.dob
+
+    def modified_more_recently(self, path: Self) -> bool:
+        """Returns whether this file or folder was modified
+        more recently than the one pointed to by 'path'."""
+        return self.mod_date > path.mod_date
+
+    def moveup(self, name: str) -> Self:
+        """Return a new Pathier object that is a parent of this instance.
         'name' is case-sensitive and raises an exception if it isn't in self.parts.
         >>> p = Pathier("C:\some\directory\in\your\system")
         >>> print(p.moveup("directory"))
@@ -37,7 +111,7 @@ class Pathier(pathlib.Path):
         return Pathier(*(self.parts[: self.parts.index(name) + 1]))
 
     def __sub__(self, levels: int) -> Self:
-        """Return a new Pathier obj moved up 'levels' number of parents from the current path.
+        """Return a new Pathier object moved up 'levels' number of parents from the current path.
         >>> p = Pathier("C:\some\directory\in\your\system")
         >>> new_p = p - 3
         >>> print(new_p)
@@ -47,6 +121,17 @@ class Pathier(pathlib.Path):
             path = path.parent
         return path
 
+    def move_under(self, name: str) -> Self:
+        """Return a new Pathier object such that the stem
+        is one level below the folder 'name'.
+        'name' is case-sensitive and raises an exception if it isn't in self.parts.
+        >>> p = Pathier("a/b/c/d/e/f/g")
+        >>> print(p.move_under("c"))
+        >>> 'a/b/c/d'"""
+        if name not in self.parts:
+            raise Exception(f"{name} is not a parent of {self}")
+        return self - (len(self.parts) - self.parts.index(name) - 2)
+
     def mkdir(self, mode: int = 511, parents: bool = True, exist_ok: bool = True):
         """Create this directory.
         Same as Path().mkdir() except
